Welcome to the SDyPy-model documentation!
===============================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   code



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
